@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2012-2016 Richard Hughes <richard@hughsie.com>
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
@@ -15,7 +15,7 @@
 G_BEGIN_DECLS
 
 /**
- * GsAppListFilterFlags:
+ * GsAppListFilterFlags: (type guint64)
  * @GS_APP_LIST_FILTER_FLAG_NONE:		No flags set
  * @GS_APP_LIST_FILTER_FLAG_KEY_ID:		Filter by ID
  * @GS_APP_LIST_FILTER_FLAG_KEY_SOURCE:		Filter by default source
@@ -70,8 +70,9 @@ void		 gs_app_list_add		(GsAppList	*list,
 						 GsApp		*app);
 void		 gs_app_list_add_list		(GsAppList	*list,
 						 GsAppList	*donor);
-void		 gs_app_list_remove		(GsAppList	*list,
+gboolean	 gs_app_list_remove		(GsAppList	*list,
 						 GsApp		*app);
+void		 gs_app_list_remove_all		(GsAppList	*list);
 GsApp		*gs_app_list_index		(GsAppList	*list,
 						 guint		 idx);
 GsApp		*gs_app_list_lookup		(GsAppList	*list,
